#vider la mmoire
rm(list=ls())

#charger les donnes
library(xlsx)
heart <- read.xlsx("heart.xlsx",sheetName = "heart")

#carac. de la base
str(heart)

#stat. sur angine et coeur
summary(heart[,c("angine","coeur")])

#association coeur, angine
#test du khi-2, sans la correction de continuit
#p-value < 0.05, l'hypothse d'indpendance est dmentie par les donnes
print(chisq.test(x=heart$angine,y=heart$coeur,correct=FALSE))

#tableau crois
tc <- table(heart$coeur,heart$angine)
print(tc)

#profil colonne
pc <- prop.table(tc,margin=2)
print(pc)

#vrification sommes en colonne
print(colSums(pc))

#risque relatif
rr <- pc["presence","oui"]/pc["presence","non"]
print(rr)

#passage au log.
lrr <- log(rr)
print(lrr)

#estimation de la variance
var_rr <- 1.0/(tc["presence","oui"])*pc["absence","oui"]+1.0/(tc["presence","non"])*pc["absence","non"]
print(var_rr)

#qauntile de la loi normale
u <- qnorm(0.975)
print(u)

#borne basse
print(exp(lrr - u * sqrt(var_rr)))

#borne haute
print(exp(lrr + u * sqrt(var_rr)))

#les bornes ne contiennent pas la valeur 1
#on peut conclure que risque relatif est significativement diffrent de 1

#epitools
library(epitools)

#calcul
print(epitools::riskratio(y=heart$coeur,x=heart$angine,method="wald"))

#odds-ratio
or <- (pc["presence","oui"]/pc["absence","oui"])/(pc["presence","non"]/pc["absence","non"])
print(or)

#log de l'odds-ratio
lor <- log(or)
print(lor)

#variance de l'odds-ratio
var_or <- sum(sapply(tc,function(x){return(1.0/x)}))
print(var_or)

#borne basse
print(exp(lor - u * sqrt(var_or)))

#borne haute
print(exp(lor + u * sqrt(var_or)))

#odds-ratio avec epitools
print(epitools::oddsratio(y=heart$coeur,x=heart$angine,method="wald"))

#rgression logistique
#angine est automatiquement recode en variable binaire 0/1
#angine = non (premire modalit par ordre alphabtique) est la modalit exclue
#angine = oui est donc celle qui a t conserve
reg <- summary(glm(coeur ~ angine, data = heart, family = binomial))
print(reg)

#atttributs
print(attributes(reg))

#type du champ "tableau des coefficients"
print(class(reg$coefficients))

#accs au champ "tableau des coefficients"
print(reg$coefficients)

#dimension "tableau des coefficients"
print(dim(reg$coefficients))

#label des lignes "tableau des coefficients"
print(rownames(reg$coefficients))

#label des colonnes "tableau des coefficients"
print(colnames(reg$coefficients))

#exp. du coefficient
print(exp(reg$coefficients["angineoui","Estimate"]))

#borne basse -- int de confiance  95% du coefficient de angine_oui
bb_angine <- reg$coefficients["angineoui","Estimate"] - u * reg$coefficients["angineoui","Std. Error"]
print(bb_angine)

#passage  l'exponentiel
print(exp(bb_angine))

#borne haute
bh_angine <- reg$coefficients["angineoui","Estimate"] + u * reg$coefficients["angineoui","Std. Error"]
print(bh_angine)

#passage  l'exponentiel
print(exp(bh_angine))

#rajouter le sexe
reg_bis <- summary(glm(coeur ~ angine + sexe, data = heart, family=binomial))
print(reg_bis)

#odds-ratio
#diffrent de la rgression simple parce angine et sexe ne sont pas indpendants
#l'odds-ratio ici fait l'hypothse qu'elle est la mme chez les hommes et les femmes
print(exp(reg_bis$coefficients["angineoui","Estimate"]))

#liaison angine et sexe
print(chisq.test(heart$angine,heart$sexe,correct=FALSE))

#odds-ratio de angine chez les femmes
print(epitools::oddsratio(heart$angine[heart$sexe=="feminin"],heart$coeur[heart$sexe=="feminin"],method="wald"))

#odds-ratio de angine chez les hommes
print(epitools::oddsratio(heart$angine[heart$sexe=="masculin"],heart$coeur[heart$sexe=="masculin"],method="wald"))

#introduire le terme d'interaction angine x sexe
#il n'est pas significatif  5%
#tre un homme atteint d'une angine n'induit pas un risque accru ou moindre d'tre malade
reg_ter <- summary(glm(coeur ~ angine * sexe, data = heart, family=binomial))
print(reg_ter)

#distribution de frquences de vaisseau
print(table(heart$vaisseau))

#variable vaisseau
#vaisseau = A est la modalit de rfrence
#les coefficients indiquent un risque accru d'tre malade lorsqu'on prsente
#une modalit de vaisseau autre que A
reg_vaisseau <- summary(glm(coeur ~ vaisseau, data = heart, family=binomial))
print(reg_vaisseau)

#exponentiel - odds-ratio par rapport  la modalit de rfrence vaisseau = A
#le coefficient li  l'intercept n'a pas d'intrt ici
apply(reg_vaisseau$coefficients,1,function(x){exp(x["Estimate"])})

#odds-ratio via epitools
print(epitools::oddsratio(y=heart$coeur,x=heart$vaisseau,method="wald"))

#tableau crois
tc_vaisseau <- table(heart$coeur,heart$vaisseau)
print(tc_vaisseau)

#odds-ratio
#B /A = comme cas nominal
#C et D = diffrents cette fois-ci puisque la modalit de rfrence est diffrente
for (j in 2:4){
  print(paste(colnames(tc_vaisseau)[j],"=",(tc_vaisseau["presence",j]/tc_vaisseau["absence",j])/(tc_vaisseau["presence",j-1]/tc_vaisseau["absence",j-1])))
}

#recodage en variable ordinale
ordinal_vaisseau <- ordered(heart$vaisseau)

#type
print(class(ordinal_vaisseau))

#valeurs
print(ordinal_vaisseau)

#recodage en indicatrices cumulatives
vais_b <- ifelse(ordinal_vaisseau >= "B",1,0)
vais_c <- ifelse(ordinal_vaisseau >= "C",1,0)
vais_d <- ifelse(ordinal_vaisseau >= "D",1,0)

#variable vaisseau ordinale
#seul le passage B/A induit ue augmentation significative du risque
#pas C/B ni D/C
reg_vaisseau_bis <- summary(glm(coeur ~ vais_b + vais_c + vais_d, data = heart, family=binomial))
print(reg_vaisseau_bis)

#passage en exponentiel
apply(reg_vaisseau_bis$coefficients,1,function(x){exp(x["Estimate"])})

#et avec epitools
#qui ne sait pas tenir compte du caractre ordinal de la variable ordinal_vaisseau
print(epitools::oddsratio(y=heart$coeur,x=ordinal_vaisseau,method="wald"))

#boxplot de depression selon coeur
#il y a un dcalage des distributions
#on peut diffrencier les valeurs de coeur avec depression
boxplot(heart$depression ~ heart$coeur)

#regression avec depression
reg_quarter <- summary(glm(coeur ~ depression, data = heart, family=binomial))
print(reg_quarter)

#odds-ratio
#augmentation de risque de maladie induite par une augmentation d'une unit de dpression
print(exp(reg_quarter$coefficients["depression","Estimate"]))

#regression avec age et depression
#on peut penser que dpression a un impact plus fort avec la z-value (ou la p-value)
reg_quinter <- summary(glm(coeur ~ age + depression, data = heart, family=binomial))
print(reg_quinter)

#odds-ratio de depression maintenant
# ge fix, l'augmentation de risque associ  une augmentation d'une unit de dpression
#hypothse induite : l'impact de dpression serait toujours le mme quelle que soit l'ge du patient
print(exp(reg_quinter$coefficients["depression","Estimate"]))

#coef. standardis - age
#augmentation du LOGIT lorsque l'ge varie d'1 ecart-type
coef_std_age <- reg_quinter$coefficients["age","Estimate"]*sd(heart$age)
print(coef_std_age)

#coef. standardis - depression
coef_std_depression <- reg_quinter$coefficients["depression","Estimate"]*sd(heart$depression)
print(coef_std_depression)

#impact relatif sur le LOGIT
print(coef_std_depression/coef_std_age)
